@@ -3,17 +3,17 @@
 /**
  * setup.php
  *
- * Copyright (c) 1999-2005 The SquirrelMail Project Team
+ * Copyright (c) 1999-2006 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
- * @version $Id: setup.php,v 1.11.2.9 2005/02/03 15:00:58 tokul Exp $
+ * @version $Id: setup.php 12256 2007-02-13 07:54:18Z jervfors $
  * @package plugins
  * @subpackage translate
  */
 
 /* Easy plugin that sends the body of the message to a new browser
 window using the specified translator.  It can also translate your
-outgoing message if you send it to someone in a different country. 
+outgoing message if you send it to someone in a different country.
 
   Languages from i18n, incorporated in the auto-language selection:
     en - English
@@ -52,14 +52,14 @@ function translate_read_form() {
     if (!$translate_show_read) {
         return;
     }
-    
+
     $translate_dir = 'to';
 
     $trans_ar = $message->findDisplayEntity(array(), array('text/plain'));
     $body = '';
-    if ($trans_ar[0] != '') {
+    if ( !empty($trans_ar[0]) ) {
         for ($i = 0; $i < count($trans_ar); $i++) {
-            $body .= formatBody($imapConnection, $message, $color, $wrap_at, $trans_ar[$i], $passed_id, $mailbox);
+            $body .= formatBody($imapConnection, $message, $color, $wrap_at, $trans_ar[$i], $passed_id, $mailbox, true);
         }
         $hookResults = do_hook('message_body', $body);
         $body = $hookResults[1];
@@ -68,11 +68,6 @@ function translate_read_form() {
     }
 
     $new_body = $body;
-    $pos = strpos($new_body,
-                  '">'. _("Download this as a file") . '</a></center><br /></small>');
-    if (is_int($pos)) {
-        $new_body = substr($new_body, 0, $pos);
-    }
 
     $trans = get_html_translation_table(HTML_ENTITIES);
     $trans[' '] = '&nbsp;';
@@ -81,17 +76,17 @@ function translate_read_form() {
 
     $new_body = urldecode($new_body);
     $new_body = strip_tags($new_body);
-              
+
     /* I really don't like this next part ... */
     $new_body = str_replace('"', "''", $new_body);
     $new_body = strtr($new_body, "\n", ' ');
-    
+
     $function = 'translate_form_' . $translate_server;
     $function($new_body);
 }
 
 /** Closes translation engine form */
-function translate_table_end() {                     
+function translate_table_end() {
     ?></td>
           </tr>
         </table>
@@ -105,7 +100,7 @@ function translate_table_end() {
 /** Unimplemented. Translation in compose*/
 function translate_button() {
     global $translate_show_send;
-  
+
     if (! $translate_show_send) {
         return;
     }
@@ -123,7 +118,7 @@ function translate_optpage_register_block() {
 }
 
 /** gets translation preferences */
-function translate_pref() { 
+function translate_pref() {
     global $username, $data_dir;
     global $translate_server, $translate_location;
     global $translate_show_send, $translate_show_read;
@@ -133,12 +128,12 @@ function translate_pref() {
     if ($translate_server == '') {
         $translate_server = 'babelfish';
     }
-    
+
     $translate_location = getPref($data_dir, $username, 'translate_location');
     if ($translate_location == '') {
         $translate_location = 'center';
     }
-    
+
     $translate_show_send = getPref($data_dir, $username, 'translate_show_send');
     $translate_show_read = getPref($data_dir, $username, 'translate_show_read');
     $translate_same_window = getPref($data_dir, $username, 'translate_same_window');
@@ -156,21 +151,21 @@ function translate_does_it_match_language($test) {
     $false = 0;
     $index = 0;
     $smindex = 0;
-  
+
     if (! $test || ! $squirrelmail_language) {
         return $false;
     }
-      
+
     if ($test[$index] == '!') {
         $index ++;
         $true = 0;
         $false = 1;
     }
-    
+
     if (($index == 0) && ($test == $squirrelmail_language)) {
         return $true;
     }
-      
+
     while (isset($test[$index]) && $test[$index]) {
         if ($test[$index] == '*') {
             return $true;
@@ -181,7 +176,7 @@ function translate_does_it_match_language($test) {
         $index ++;
         $smindex ++;
     }
-      
+
     return $false;
 }
 
@@ -204,28 +199,38 @@ function translate_lang_opt($from, $to, $value, $text) {
     return( $ret );
 }
 
-/** starts translation engine form */
-function translate_new_form($action) {
+/**
+ * Starts translation box
+ *
+ * @param string $action url that has to recieve message for translation
+ * @param string $charset (since sm 1.5.1 and 1.4.9) character set, that
+ * should be used to submit 8bit information.
+ * @access private
+ */
+function translate_new_form($action,$charset=null) {
     global $translate_dir, $translate_new_window, $translate_location;
     global $color, $translate_same_window;
 
     echo '<form action="';
-  
+
     if ($translate_dir == 'to') {
         echo $action;
     } else {
         echo 'translate.php';
     }
-  
+
     echo '" method="post"';
-  
+
     if (!$translate_same_window) {
         echo ' target="_blank"';
     }
 
+    if (! is_null($charset))
+        echo ' accept-charset="'.htmlspecialchars($charset).'"';
+
     echo ">\n";
 
-    ?><table align="<?php echo $translate_location ?>" cellpadding="3" 
+    ?><table align="<?php echo $translate_location ?>" cellpadding="3"
         cellspacing="0" border="0" bgcolor="<?php echo $color[10] ?>">
     <tr>
       <td>
@@ -246,7 +251,7 @@ function translate_form_babelfish($message) {
     <input type="hidden" name="doit" value="done" />
     <input type="hidden" name="intl" value="1" />
     <input type="hidden" name="tt" value="urltext" />
-    <input type="hidden" name="urltext" value="<?php echo $message; ?>" />
+    <input type="hidden" name="urltext" value="<?php echo htmlspecialchars($message); ?>" />
     <select name="lp"><?php
         echo translate_lang_opt('zh_CN',  '',     'zh_en',
                             sprintf( _("%s to %s"),_("Chinese, Simplified"),_("English"))) .
@@ -686,11 +691,8 @@ function translate_form_promt($message) {
  * @access private
  */
 function translate_form_google($message) {
-    translate_new_form('http://www.google.com/translate_t');
-    echo '<input type="hidden" name="ie" value="Unknown" />' .
-         '<input type="hidden" name="oe" value="ASCII" />' .
-         '<input type="hidden" name="hl" value="en" />' .
-         '<input type="hidden" name="text" value="' . $message . '" />';
+    translate_new_form('http://www.google.com/translate_t','utf-8');
+    echo '<input type="hidden" name="text" value="' . $message . '" />';
     echo '<select name="langpair">'.
          translate_lang_opt('en_US', 'de_DE', 'en|de',
                             sprintf( _("%s to %s"),_("English"),_("German"))) .
@@ -702,6 +704,14 @@ function translate_form_google($message) {
                             sprintf( _("%s to %s"),_("English"),_("Italian"))) .
          translate_lang_opt('en_US', 'pt*',   'en|pt',
                             sprintf( _("%s to %s"),_("English"),_("Portuguese"))) .
+         translate_lang_opt('en_US', 'ar',    'en|ar',
+                            sprintf( _("%s to %s"),_("English"),_("Arabic"))) .
+         translate_lang_opt('en_US', 'ja_JP', 'en|ja',
+                            sprintf( _("%s to %s"),_("English"),_("Japanese"))) .
+         translate_lang_opt('en_US', 'ko_KR', 'en|ko',
+                            sprintf( _("%s to %s"),_("English"),_("Korean"))) .
+         translate_lang_opt('en_US', 'zh_CN', 'en|zh-CN',
+                            sprintf( _("%s to %s"),_("English"),_("Chinese, Simplified"))) .
          translate_lang_opt('de_DE', 'en_US', 'de|en',
                             sprintf( _("%s to %s"),_("German"),_("English"))) .
          translate_lang_opt('de_DE', '', 'de|fr',
@@ -715,10 +725,20 @@ function translate_form_google($message) {
          translate_lang_opt('it_IT', '', 'it|en',
                             sprintf( _("%s to %s"),_("Italian"),_("English"))) .
          translate_lang_opt('pt*',   '', 'pt|en',
-                            sprintf( _("%s to %s"),_("Portuguese"),_("English")));
+                            sprintf( _("%s to %s"),_("Portuguese"),_("English"))).
+         translate_lang_opt('ar',    '', 'ar|en',
+                            sprintf( _("%s to %s"),_("Arabic"),_("English"))).
+         translate_lang_opt('ja_JP', '', 'ja|en',
+                            sprintf( _("%s to %s"),_("Japanese"),_("English"))).
+         translate_lang_opt('ko_KR', '', 'ko|en',
+                            sprintf( _("%s to %s"),_("Korean"),_("English"))).
+         translate_lang_opt('zh_CN', '', 'zh-CN|en',
+                            sprintf( _("%s to %s"),_("Chinese, Simplified"),_("English")));
     echo '</select>'.
-         'Google: <input type="submit" value="' . _("Translate") . '" />';
+        '<input type="hidden" name="hl" value="en" />' .
+        '<input type="hidden" name="ie" value="UTF8" />' .
+        '<input type="hidden" name="oe" value="UTF8" />' .
+        'Google: <input type="submit" value="' . _("Translate") . '" />';
 
     translate_table_end();
 }
-?>
\ No newline at end of file
