@@ -3,14 +3,17 @@
 /**
  * move_messages.php
  *
- * Copyright (c) 1999-2006 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
- *
  * Enables message moving between folders on the IMAP server.
  *
- * $Id: move_messages.php,v 1.81.2.9 2006/02/03 22:27:55 jervfors Exp $
+ * @copyright &copy; 1999-2007 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: move_messages.php 12542 2007-07-16 21:04:37Z kink $
+ * @package squirrelmail
  */
 
+/** This is the move_messages page */
+define('PAGE_NAME', 'move_messages');
+
 /* Path for SquirrelMail required files. */
 define('SM_PATH','../');
 
@@ -29,7 +32,7 @@ if ( !sqgetGlobalVar('composesession', $composesession, SQ_SESSION) ) {
 
 function attachSelectedMessages($msg, $imapConnection) {
     global $username, $attachment_dir, $startMessage,
-           $data_dir, $composesession, $uid_support,
+           $data_dir, $composesession, $uid_support, $mailbox,
        $msgs, $thread_sort_messages, $allow_server_sort, $show_num,
        $compose_messages;
 
@@ -66,18 +69,19 @@ function attachSelectedMessages($msg, $imapConnection) {
     while ($j < count($msg)) {
         if (isset($msg[$i])) {
             $id = $msg[$i];
+            
             $body_a = sqimap_run_command($imapConnection, "FETCH $id RFC822",true, $response, $readmessage, $uid_support);
-
+            
             if ($response == 'OK') {
+                $message = sqimap_get_message($imapConnection, $id, $mailbox);
 
-                // fetch the subject for the message with $id from msgs.
-                // is there a more efficient way to do this?
-                foreach($msgs as $k => $vals) {
-                    if($vals['ID'] == $id) {
-                        $subject = $msgs[$k]['SUBJECT'];
-                        break;
-                    }
+                // fetch the subject for the message from the object
+                $filename = $message->rfc822_header->subject;
+                if ( empty($filename) ) {
+                    $filename = "untitled-".$message->entity_id;
                 }
+                $filename .= '.msg';
+                $filename = decodeHeader($filename, false, false);
 
                 array_shift($body_a);
                 array_pop($body_a);
@@ -86,12 +90,16 @@ function attachSelectedMessages($msg, $imapConnection) {
 
                 $localfilename = GenerateRandomString(32, 'FILE', 7);
                 $full_localfilename = "$hashed_attachment_dir/$localfilename";
+                while (file_exists($full_localfilename)) {
+                    $localfilename = GenerateRandomString(32, 'FILE', 7);
+                    $full_localfilename = "$hashed_attachment_dir/$localfilename";
+                }
 
                 $fp = fopen( $full_localfilename, 'wb');
                 fwrite ($fp, $body);
                 fclose($fp);
-                $composeMessage->initAttachment('message/rfc822',$subject.'.msg',
-                     $full_localfilename);
+                $composeMessage->initAttachment('message/rfc822',$filename,
+                     $localfilename);
             }
             $j++;
         }
@@ -139,6 +147,9 @@ $location = set_url_var($location,'composenew',0,false);
 $location = set_url_var($location,'composesession',0,false);
 $location = set_url_var($location,'session',0,false);
 
+// make sure that cache is not used
+$location = set_url_var($location,'use_mailbox_cache',0,false);
+
 /* remember changes to mailbox setting */
 if (!isset($lastTargetMailbox)) {
     $lastTargetMailbox = 'INBOX';
@@ -217,20 +228,22 @@ if(isset($expungeButton)) {
         $exception = true;
     }
 } else {    // Move messages
-
     if (count($id)) {
-        sqimap_msgs_list_copy($imapConnection,$id,$targetMailbox);
-        if ($auto_expunge) {
-            $cnt = sqimap_mailbox_expunge($imapConnection, $mailbox, true);
-        } else {
-            $cnt = 0;
-        }
-
-        if (($startMessage+$cnt-1) >= $mbx_response['EXISTS']) {
-            if ($startMessage > $show_num) {
-                $location = set_url_var($location,'startMessage',$startMessage-$show_num, false);
+        // move messages only when target mailbox is not the same as source mailbox
+        if ($mailbox!=$targetMailbox) {
+            sqimap_msgs_list_copy($imapConnection,$id,$targetMailbox);
+            if ($auto_expunge) {
+                $cnt = sqimap_mailbox_expunge($imapConnection, $mailbox, true);
             } else {
-                $location = set_url_var($location,'startMessage',1, false);
+                $cnt = 0;
+            }
+
+            if (($startMessage+$cnt-1) >= $mbx_response['EXISTS']) {
+                if ($startMessage > $show_num) {
+                    $location = set_url_var($location,'startMessage',$startMessage-$show_num, false);
+                } else {
+                    $location = set_url_var($location,'startMessage',1, false);
+                }
             }
         }
     } else {
@@ -247,4 +260,4 @@ if ($exception) {
     exit;
 }
 ?>
-</BODY></HTML>
\ No newline at end of file
+</body></html>
